@@ -453,17 +453,6 @@ namespace fsw
      */
     bool accept_path(const std::string& path) const;
 
-    /**
-     * @brief Check whether a path should be accepted.
-     *
-     * This function checks @p path against the path filters of the monitor to
-     * determine whether it should be _accepted_.
-     *
-     * @param event_type The path to check.
-     * @return @c true if the path is accepted, @c false otherwise.
-     */
-    bool accept_path(const char *path) const;
-
     /**
      * @brief Notify change events.
      *
@@ -606,11 +595,15 @@ namespace fsw
      * threads.
      */
     mutable std::mutex run_mutex;
+
+    /**
+     * @brief Mutex used to serialize access to the notify_events() method.
+     */
+    mutable std::mutex notify_mutex;
 #  endif
 
   private:
     std::chrono::milliseconds get_latency_ms() const;
-
     std::vector<compiled_monitor_filter> filters;
     std::vector<fsw_event_type_filter> event_type_filters;
 
